device_preview_shot library

Classes

AccessibilitySection
All the simulated accessibility settings.
CustomDeviceInfoData
Info about a device and its frame.
DeviceFrame
Simulate a physical device and embedding a virtual screen into it.
DeviceFrameStyle
The device frame style only allows to update the keyboardStyle for now.
DeviceFrameTheme
The theme gives a style to all its descentant device frames.
DeviceIdentifier
A unique identifier that represents a device.
DeviceInfo
Info about a device and its frame.
DeviceKeyboardStyle
The keyboard style allows to customize the virtual onscreen keyboard visuals.
DevicePreviewData
A DevicePreviewShot configuration snapshot that can be serialized to be persisted between sessions.
DevicePreviewSettingsData
Settings of device preview itself (tool bar position, background style).
DevicePreviewShot
Simulates how the result of builder would render on different devices.
DevicePreviewState
Represents the current state of the device preview.
DevicePreviewStorage
A storage for device preview user's preferences.
DevicePreviewStore
The store is a container for the current state of the device preview.
DevicePreviewWidgetState
Devices
A list of common device specifications sorted by target platform.
DeviceScreenshot
A screenshot from a preview.
DeviceSection
All the simulated properties for the device.
FileDevicePreviewStorage
A storage that saves device preview user preferences into a single file as json content.
GenericDesktopMonitorFramePainter
GenericLaptopFramePainter
GenericPhoneFramePainter
GenericTabletFramePainter
NamedLocale
A locale that has a display name.
NoDevicePreviewStorage
A storage that keep preferences only in memory : they are reset on each fresh start of the app.
PreferencesDevicePreviewStorage
Since share_preferences makes pub considering the package as not supported we should remove this functionality from the web version to get the maximum score.
ScreenshotSection
A tool panel section that allows taking screenshots.
SettingsSection
All the settings for customizing the preview.
SystemSection
All the simulated system settings.
ToolPanelSection
A section in the tool panel.
VirtualKeyboard
Display a simulated on screen keyboard at the bottom of a child widget.

Enums

ColorBlindnessType
The types of color blindness that can be simulated.
DevicePreviewBackgroundThemeData
DevicePreviewToolBarPositionData
DevicePreviewToolBarThemeData
DeviceType
A device form factor.

Extensions

CustomDeviceInfoDataPatterns on CustomDeviceInfoData
Adds pattern-matching-related methods to CustomDeviceInfoData.
DeviceInfoExtension on DeviceInfo
DevicePreviewDataPatterns on DevicePreviewData
Adds pattern-matching-related methods to DevicePreviewData.
DevicePreviewSettingsDataPatterns on DevicePreviewSettingsData
Adds pattern-matching-related methods to DevicePreviewSettingsData.
DevicePreviewStateHelperExtensions on DevicePreviewStore
A set of extension to triggers updates of the state.
DevicePreviewStatePatterns on DevicePreviewState
Adds pattern-matching-related methods to DevicePreviewState.

Constants

defaultAvailableLocales → const List<NamedLocale>
A set of many named locales.

Functions

basicLocaleListResolution(List<Locale>? preferredLocales, Iterable<Locale> supportedLocales) → Locale
buildGenericDesktopMonitorDevice({required TargetPlatform platform, required String id, required String name, required Size screenSize, required Rect windowPosition, EdgeInsets safeAreas = EdgeInsets.zero, double pixelRatio = 2.0, EdgeInsets? rotatedSafeAreas, GenericDesktopMonitorFramePainter? framePainter}) → DeviceInfo
Creates a generic desktop monitor device definition for the given name, target platform and screenSize. The windowPosition defines the position of a virtual window with a window frame adapted for the given platform.
buildGenericLaptopDevice({required TargetPlatform platform, required String id, required String name, required Size screenSize, required Rect windowPosition, EdgeInsets safeAreas = EdgeInsets.zero, double pixelRatio = 2.0, EdgeInsets? rotatedSafeAreas, GenericLaptopFramePainter? framePainter}) → DeviceInfo
Creates a generic laptop device definition.
buildGenericPhoneDevice({required TargetPlatform platform, required String id, required String name, required Size screenSize, EdgeInsets safeAreas = EdgeInsets.zero, EdgeInsets rotatedSafeAreas = EdgeInsets.zero, double pixelRatio = 2.0, GenericPhoneFramePainter framePainter = const GenericPhoneFramePainter()}) → DeviceInfo
Creates a generic phone device definition.
buildGenericTabletDevice({required TargetPlatform platform, required String id, required String name, required Size screenSize, EdgeInsets safeAreas = EdgeInsets.zero, EdgeInsets rotatedSafeAreas = EdgeInsets.zero, double pixelRatio = 2.0, GenericTabletFramePainter framePainter = const GenericTabletFramePainter()}) → DeviceInfo
Creates a generic tablet device definition.