DeviceIdentifier class

A unique identifier that represents a device.

See also :

  • loadDeviceInfo to load information store in assets.
  • DeviceFrame to display the frame associated to one of identifiers.

Constructors

DeviceIdentifier(TargetPlatform platform, DeviceType type, String name)
Private constructor.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
The unique name of the device (preferably in snake case).
final
platform → TargetPlatform
The target platform supported by this device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DeviceType
The device form factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override